/* CSuperViewDivider.h - a divider that, during a mouse drag divides the view of
		its parent, not just itself, and at the end of its drag sends the parent
		a MoveDividerBy message (so a group of dividers can move in unison.)

	Version 1.4 Jan 2002
	1.1 rev'ed: fix incompatibilities introduced in Pro 2
	1.2 bug fixes in CViewColumn.cp when adding panes into scrolled views.
	1.3 rev'ed: fix incompatibilities introduced in Pro 5.3
	1.4 rev'ed: fix incompatibilities introduced in Pro 7.1
	Copyright 1997-2002 by David Phillip Oster <mail-to:oster@ieee.org>

	The semi-legal stuff:
 
	You may use this any way you see fit, but:
		by your use of this you this you agree to hold David Oster harmless of any liability
			that may result from your use of this.
	You may not remove David Oster's name and contact info from the source code, although you
		may add your own.
	You agree to e-mail David Oster about bugs and problems with this source code.
 */
#pragma once

#include "CViewDivider.h"

/* CViewDividerOwner - the owner of a CSuperViewDivider must inherit from this class.
	and implement GetSubPanes() as the commented out code.
 */
class CViewDividerOwner {
public:
	CViewDividerOwner(){}
	virtual ~CViewDividerOwner(){}
	virtual void	MoveDividerBy(SInt16 dx, SInt16 dy, Boolean inRefresh);
	virtual TArray<LPane*>& GetSubPanes() = 0; // { return mSubPanes; }
};

/* CSuperViewDivider - 
 */
class CSuperViewDivider : public CViewDivider {
public:
	enum { class_ID = 'Sviw' };

	CSuperViewDivider(LStream *inStream);

	virtual void	DrawSelf();

	virtual void	GetDragLimitSlop(Rect& outR, Rect& outLimitR, Rect& outSlopR);

	virtual void	MoveDividerBy(SInt16 dx, SInt16 dy, Boolean inRefresh);
};
