/* CViewDivider.h - a view that implements a mouse-draggable pane divider between two subviews.

	Note: determines at creation time whether it is a horizontal or a vertical divider.
		depends on the programmer to create a gap between the two subviews.
		CanVanish=false is not yet implemented.

	Version 1.4 Jan 2002
	1.1 rev'ed: fix incompatibilities introduced in Pro 2
	1.2 bug fixes in CViewColumn.cp when adding panes into scrolled views.
	1.3 rev'ed: fix incompatibilities introduced in Pro 5.3
	1.4 rev'ed: fix incompatibilities introduced in Pro 7.1
	Copyright 1997-2002 by David Phillip Oster <mail-to:oster@ieee.org>

	The semi-legal stuff:
 
	You may use this any way you see fit, but:
		by your use of this you this you agree to hold David Oster harmless of any liability
			that may result from your use of this.
	You may not remove David Oster's name and contact info from the source code, although you
		may add your own.
	You agree to e-mail David Oster about bugs and problems with this source code.
 */
#pragma once

#ifndef curs_HorizontalDivider
#define curs_HorizontalDivider	1128
#endif

#ifndef curs_VerticalDivider
#define curs_VerticalDivider	1129
#endif


class CViewDivider : public LView {
public:
	enum { class_ID = 'Dviw' };
	typedef LView inherited;

	CViewDivider(LStream *inStream);
	virtual ~CViewDivider();

	virtual void	FinishCreateSelf();
	virtual void	ClickSelf(const SMouseDownEvent& inMouseDown);
	virtual void	DrawSelf();
	virtual void	AdjustMouseSelf(Point inPortPt, const EventRecord&	inMacEvent, RgnHandle ioMouseRgn);
	virtual void	AdaptToSuperFrameSize(
							SInt32	inSurrWidthDelta,
							SInt32	inSurrHeightDelta,
							Boolean	inRefresh);

	virtual void	MoveDividerBy(SInt16	dx, SInt16 dy, Boolean inRefresh);
	virtual void	MoveDividerBySelf(SInt16	dx, SInt16 dy, Boolean inRefresh);

protected:

	virtual void	RecalcIsHorizontal();	// used to initialize mIsHorizontal
	virtual void	RecalcFirstRatio();
	virtual void	GetDividerRect(Rect& r);
	virtual void	GetDragLimitSlop(Rect& outR, Rect& outLimitR, Rect& outSlopR);

	ResIDT	mFirstID;
	SInt16	mFirstMinSize;		// if non-zero, the minimum size for this pane.
	Boolean	mFirstCanVanish;	// can a pane with a minimum vanish?

	ResIDT	mSecondID;
	SInt16	mSecondMinSize;		// if non-zero, the minimum size for this pane.
	Boolean	mSecondCanVanish;	// can a pane with a minimum vanish?

	float	mFirstRatio;		// of first / whole. (use this to restore proportions after a shrink to zero)
	Boolean	mIsHorizontal;		// i.e, subpanes are arranged horizontally = side by side.
};
